// @ts-check
const { join } = require('path')
const fs = require('fs-extra')

/**
 * @param {import('./../index').BuildVueLibRequest} request
 * @returns {import('bili').Config}
 */
module.exports = request => {
  const pkgFile = join(request.rootDir, 'package.json')
  const pkg = JSON.parse(fs.readFileSync(pkgFile, 'utf-8'))
  const name = pkg.name
  const version = pkg.version
  return {
    bundleNodeModules: true,
    banner: `
/**
 * ${name}
 * Version: ${version},
 * (c) Christian Kienle, ${new Date().getFullYear()}
 * LICENCE: MIT
 * https://github.com/ChristianKienle/cdk
*/`,
    babel: {
      configFile: false, //join(__dirname, 'bili-babel.config.js'),
      babelrc: false
    },
    plugins: {
      vue: true,
      commonjs: true
    },
    output: {
      // This will generate a single css file for all the custom styles we need in Fundamental Vue.
      extractCSS: true,
      format: ['cjs', 'umd-min', 'umd', 'es', 'es-min'],
      dir: join(request.rootDir, 'dist'),
      moduleName: name,
      fileName: context => `${name}.${context.format}${context.minify ? '.min' : ''}.js`
    },
    globals: {
      vue: 'Vue'
    }
  }
}

// bili --bundle-node-modules --file-name vue-cdk@link.[format].js --format cjs --format umd-min --format es --module-name VueCdkLink --env.NODE_ENV production -d dist